#pragma rtGlobals=1		// Use modern global access method.

//	This pair of functions adds or removes blank lines between cores from data sets for individual holes. The
//		blanks are primarily a plotting devide to avoid staight line segments between data from individual cores
//		when plotting versus CCSF ( mcd ). 

	***************************************************************
	
	Function Add_NaNs( )
		SetDataFolder root:
			String Hole, Technique
			String/G G_Hole, G_Technique
			Hole = G_Hole; Technique = G_Technique
			String Site, Folder, WvList, WvName, NonTextWvList
			Prompt Hole, "Hole"
			Prompt Technique, "Technique (e.g. GRA, RSC, XRF, etc):"
			DoPrompt "Add_Nans", Hole, Technique; AbortOnValue V_Flag, 0
			Add_NaNs_F( Hole, Technique )
			Print "Add_NaNs_F( \"" + Hole + "\", \"" + Technique + "\" )"	
	End

	***************************************************************
	
	Function Add_NaNs_F( Hole, Technique )
		String Hole, Technique
		SetDataFolder root:
			String/G G_Hole, G_Technique
			String Site, Folder, WvList, WvName, NonTextWvList
			Variable i, j, Pnts // i is the point counter, j is used to rotate through the data waves for point insertion
			PauseUpdate
			G_Hole = Hole; G_Technique = Technique
			Site = RemoveEnding( Hole )
		SetDataFolder $"root:" + Site + "_" + Technique
			WAVE CoreWv = $Hole + "_" + Technique + "_Core"
			Duplicate/O CoreWv Test
			Differentiate CoreWv/D = Test  // This command yields a string of zeros interrupted by positive values when the core number increases
			WvList = WaveList( Hole + "*", ";", "" )
			NonTextWvList = WaveList( Hole + "*", ";", "TEXT:0" )
			Pnts = NumPnts( CoreWv )
			For( i = Pnts; i > 0; i -= 1 )
				If( Test[ i ] > 0 )
					For( j = 0; j < ItemsInList( WvList ); j += 1 ) // This loop inserts a blank line in each targeted wave at a change of core
						WvName = StringFromList( j, WvList )
						InsertPoints( i ), 1, $WvName
					EndFor
				For( j = 0; j < ItemsInList( NonTextWvList ); j += 1 ) // This loop replaces zeros in the blank lines with NaNs for the numerical waves
						WvName = StringFromList( j, NonTextWvList )
						WAVE NonTextWv = $WvName
						NonTextWv[ i ] = NaN
				EndFor
					i -= 1
				EndIf
			EndFor			
			KillWaves Test
		SetDataFolder root:
	End
	
	***************************************************************
	
	Function Remove_NaNs( )
		SetDataFolder root:
			String Hole, Technique
			String/G G_Hole, G_Technique
			Hole = G_Hole; Technique = G_Technique
			String Site, Folder, WvList, NonTextWvList
			Variable i, j, Pnts
			Prompt Hole, "Hole"
			Prompt Technique, "Technique (e.g. GRA, RSC, XRF, etc):"
			DoPrompt "Remove_Nans", Hole, Technique; AbortOnValue V_Flag, 0
			Remove_NaNs_F( Hole, Technique )
			Print "Remove_NaNs_F( \"" + Hole + "\", \"" + Technique + "\" )"	
	End

	***************************************************************
	
	Function Remove_NaNs_F( Hole, Technique )
		String Hole, Technique
		SetDataFolder root:
			String/G G_Hole, G_Technique
			String Site, Folder, WvList, NonTextWvList
			Variable i, j, Pnts
			PauseUpdate;
			G_Hole = Hole; G_Technique = Technique
			Site = RemoveEnding( Hole )
		SetDataFolder Site + "_" + Technique
			NonTextWvList = WaveList( Hole + "*", ";", "TEXT:0" )
			WvList = WaveList( Hole + "*", ";", "" )
			Pnts = NumPnts( $StringFromList( 0, Wvlist ) )
			For( i = Pnts; i > 0; i -= 1 )
				WAVE W0 = $StringFromList( 0, NonTextWvList ), W1 = $StringFromList( 1, NonTextWvList ), W2 = $StringFromList( 2, NonTextWvList )
				If( NumType( W0[ i ] ) == 2 && NumType( W1[ i ] ) == 2 && NumType( W2[ i ] ) == 2 )
					For( j = 0; j < ItemsInList( WvList ); j += 1 )
						Wave Wv = $StringFromList( j, WvList )
						DeletePoints i, 1, Wv
					EndFor
				EndIf
			EndFor
		SetDataFolder root:
	End
