#pragma rtGlobals=1		// Use modern global access method.

	// Takes all of the section images in the K_ folder and combines them into a core image. May apply a lighting correction as
	// user prefers. Section Images may be saved ( best practice for images from core table photos, otherwise not necessary ).
	
	// After some preliminaries, the macro creates a blank core image of the proper length and resolution, and then succesively copies
	// the section images into the blank core image.
	
	// Last changed 6/22/2017 to add resolution to core image assembly and possibility of going directly to smaller ( S2 ) image sizes.
	//		Also added feature to create image folders automatically.
	
	*************************************************************************************************************

	Function Assemble_Core_Image(  )
		SetDataFolder root:
			String/G G_Hole, G_YesNo, G_Save_K, G_S2_YesNo
			Variable/G G_Core_Num, G_SectionNum, G_Section, G_Resolution
			String S_Hole = G_Hole, S_Core = Num2Str( G_Core_Num ), Correction = G_YesNo, Save_K = G_Save_K
			String S2_YesNo = G_S2_YesNo
			Variable Resolution = G_Resolution
			String K_List, S_Core_Name, Section, S1, S2
			Prompt S_Hole, "Hole:";
			Prompt S_Core, "Core:";
			Prompt Resolution, "Resolution ( m ):";
			Prompt S2_YesNo, "Add \"S2_\" to core image name?", popup, "Y;N";
			Prompt Correction, "Apply Lighting Correction?", popup, "Y;N";
			Prompt Save_K, "Save Section ( K_ ) Files?", popup, "Y;N";
			DoPrompt "Assemble_Core_Image" S_Hole, S_Core, Resolution, S2_YesNo, Correction, Save_K; AbortOnValue V_Flag, 0
			G_Hole = S_Hole; G_YesNo = Correction; G_Save_K = Save_K; G_Core_Num = Str2Num( S_Core )  // Resets some globals to local values
			G_Resolution = Resolution; G_S2_YesNo = S2_YesNo
			Assemble_Core_Image_F( S_Hole, S_Core, Resolution, S2_YesNo, Correction, Save_K )
			Print "Assemble_Core_Image_F( \"" + S_Hole + "\", \"" + S_Core + "\", " + Num2Str( Resolution ) + ", \"" + S2_YesNo + "\", \"" + Correction + "\", \"" + Save_K + "\" )"
	End	

************************************************************************************
	
	Function Assemble_Core_Image_F( S_Hole, S_Core, Resolution, S2_YesNo, Correction, Save_K )
		String S_Hole, S_Core, Correction, Save_K, S2_YesNo
		Variable Resolution
		SetDataFolder root:
			String/G G_Hole, G_YesNo, G_Save_K
			Variable/G G_Core_Num, G_SectionNum, G_Section, G_Resolution = Resolution
			String K_List, S_Core_Name, Section, S1, S2
			G_Hole = S_Hole; G_YesNo = Correction; G_Save_K = Save_K; G_Core_Num = Str2Num( S_Core )  // Resets some globals to local values
			PauseUpdate;
		
			If( G_Core_Num < 10 )		// Makes sure that core image numbers < 10 have a zero in front of the number in the wave name
				S_Core = "0" + S_Core
			EndIf
			S_Core_Name = S_Hole + "_" + S_Core		// Creates the core name from the hole and core number
			String Folder = "root:K_" + S_Core_Name

			If( StringMatch( S2_YesNo, "Y" ) )  // Identifies the core image as lower resolution by adding "S2_" to the front of the name.
				S_Core_Name = "S2_" + S_Core_Name
				NewDataFolder/O  $S_Hole + "_S2" // Creates a folder to hold new images
			Else
				S_Core_Name = S_Core_Name
				NewDataFolder/O  $S_Hole + "_S1"				
			EndIf
			Print S_Core_Name		
	
			If( DataFolderExists( Folder ) )
				SetDataFolder $Folder
			Else
				ABORT "Can't find the \"K_\" DataFolder with the section images in root: \rYou may need to remove the core Type from the folder name for older K folders."
			EndIf
			If( !StrLen( WaveList( "*", ";", "" ) ) )
				ABORT "The \"K_\" DataFolder in root: appears to be empty. "
			EndIf
	
			String ImageFldr = GetDataFolder( 1 )
	
			If( StringMatch( Correction, "Y" ) || StringMatch( Correction, "y" ) )  // Checks to see whether lighting correction is applied
				Lighting_Correction_by_Core_DF(  )
				RGB_Lighting_Correction_DF()
				K_List = SortList( WaveList( "C_*", ";", "" ) ) // List of Section Images (Note that this change from the line below is to accomodate non-ocean drilling names)
			Else
				K_List = SortList( WaveList( "K_*", ";", "" ) ) // List of Section Images (Note that this change from the line below is to accomodate non-ocean drilling names)
			EndIf
		
			Variable i = 0, Top_Depth, Bottom_Depth, Y_Resolution, Y_Points, Section_Bottom, Section_Top, Length
		
			Top_Depth = LeftX( $StringFromList( 0, K_List ) )	// Copies top depth of core image from top of first section image
			S1 = StringFromList( ItemsInList( K_List ) - 1, K_List )			// Next 3 steps set length (in m) of new core image using bottom depth of last section image
			Bottom_Depth = RightX( $S1 )
			Length = Bottom_Depth - Top_Depth
		
			Do										// This loop copies the section images into a blank core image
				Section = StringFromList( i, K_List )			// Pulls section name from list of section images							
				If( StrLen( Section ) < 2 )						// Checks for end of list
					Break;
				EndIf
				WAVE Sect = $Section
				If( i == 0 )										// First time through, a blank core image is formed
					Y_Resolution = DimDelta( Sect, 1 )		// These 2 lines copy the Y resolution from the section images
					Y_Points = DimSize( Sect, 1 )
					Make/B/O/N=( ( Length / Resolution ), Y_Points, 3 ) $S_Core_Name // Makes the core image Length/Resolution depth points
					WAVE Core = $S_Core_Name
					SetScale/P x Top_Depth, Resolution, "m", Core			// Sets depth (X) scale
					SetScale/P y DimOffset( Sect, 1 ), Y_Resolution, "", Core  // Sets Y scale
				EndIf	
		
				Section_Top = LeftX( Sect )		// gets section top depth from section image 
				Section_Bottom = RightX( Sect )	// gets section bottom depth from section image
				Variable SecPixLen = ( ( Section_Bottom - Section_Top ) / Resolution ) + 1  // Calculates number of pixels needed at core image resolution
				ImageInterpolate/RESL = { SecPixLen, 101 } /DEST = NewSection bilinear Sect;  // Interpolates section image to new image at input resolution
				Redimension/B/U NewSection  // Sets image to 8 bit unsigned integer
		
				Core[ X2Pnt( Core, Section_Top ), X2Pnt( Core,Section_Bottom ) ][][] = NewSection[ p - X2Pnt( Core, Section_Top ) ][ q ][ r ]	// Copies section image into core image
				i += 1
			While( 1 )
		
			If( StringMatch( Correction, "Y" ) || StringMatch( Correction, "y" ) )  // Checks to see whether lighting correction is applied and adds a Wave Note
				Note $S_Core_Name "Lighting Corrected"				//
			EndIf
			If( StringMatch( S2_YesNo, "Y" ) )
				Duplicate/O Core $"root:" + S_Hole + "_S2:" + S_Core_Name // Copies core image into root:
				WAVE Image = $"root:" + S_Hole + "_S2:" + S_Core_Name
			Else
				Duplicate/O Core $"root:" + S_Hole + "_S1:" + S_Core_Name // Copies core image into root:
				WAVE Image = $"root:" + S_Hole + "_S1:" + S_Core_Name
			EndIf			
			KillWaves/Z Core, NewSection  // Deletes core image and final interpolated section image in section image folder
			
			If( StringMatch( Correction, "Y" ) || StringMatch( Correction, "y" ) ) // If lighting correction was applied, gets rid of temporary corrected section waves
				S1 = WaveList( "C_*", ",", "" )
				i = 0;
				Do
					S2 = StringFromList( i, S1 )
					If( StrLen( S2 ) < 2 )
						Break;
					EndIf
					EXECUTE "KillWaves " + S2
					i += 1	
				While( 1 ) 	
			EndIf
	
			If ( !StringMatch( GetDataFolder( 0 ) , "*root*" ) )
				If( StringMatch( Save_K, "N" ) || StringMatch( Save_K, "n" ) ) 
					KillWaves/F/A/Z
				EndIf
	
				DFREF DFldr = GetDataFolderDFR( )
		SetDataFolder root:
		
				If( StringMatch( Save_K, "N" ) || StringMatch( Save_K, "n" ) ) // save raw section images into new data folder
					KillDataFolder/Z DFldr
				EndIf
			EndIf
	
			WAVE Section_End_Pixel
			If( Exists( "Section_End_Pixel" ) ) 		// Resets pixel section end wave to NaN for core box photos
				Section_End_Pixel = NaN
			EndIf
			
			G_Section = 1						// Resets Section number to 1 for Section_Cut()
			If( !mod( Str2Num( S_Core ), 5 ) )		// Saves experiment every 5 tiimes the macro is run
				SaveExperiment
			EndIf
			DoWindow Core_Image				// This line and the following If statement check to see if a core image is already open
			If( V_Flag )							// If it is, the window is closed
				KillWindow Core_Image
			EndIf
			Redimension/B/U Image	// The new core image is changed to an unsigned bit format if the section images were not already
			Display/W=( 620, 96,1850, 264 )		// Opens blank graph
			DoWindow/C Core_Image			// Changes name of blank graph
			AppendImage Image		// Appends core image to blank graph
			ModifyGraph nticks( bottom ) = 20, minor( bottom ) = 1		// Sets a few graph mods
			SetAxis/A/R left
			G_Core_Num += 1;	G_SectionNum = 1		// Reset a couple of globals for the next run
	EndMacro
		
	
	*************************************************************************************************************
	
	*************************************************************************************************************

//	Function Assemble_Core_Image(  )
		String S_Hole, S_Core, Correction, Save_K
		SetDataFolder root:
			String/G G_Hole, G_YesNo, G_Save_K
			Variable/G G_Core_Num, G_SectionNum, G_Section
			S_Hole = G_Hole; S_Core = Num2Str( G_Core_Num ); Correction = G_YesNo, Save_K = G_Save_K
			String K_List, S_Core_Name, Section, S1, S2
			Prompt S_Hole, "Hole:";
			Prompt S_Core, "Core:";
			Prompt Correction, "Apply Lighting Correction?", popup, "Y;N";
			Prompt Save_K, "Save Section ( K_ ) Files?", popup, "Y;N";
			DoPrompt "Assemble_Core_Image" S_Hole, S_Core, Correction, Save_K; AbortOnValue V_Flag, 0
			G_Hole=S_Hole; G_YesNo = Correction; G_Save_K = Save_K; G_Core_Num = Str2Num( S_Core )  // Resets some globals to local values
			Assemble_Core_Image_F( S_Hole, S_Core, Correction, Save_K )
			Print "Assemble_Core_Image_F( \"" + S_Hole + "\", \"" + S_Core + "\", \"" + Correction + "\", \"" + Save_K + "\" )"
	End	

************************************************************************************
	
//	Function Assemble_Core_Image_F( S_Hole, S_Core, Correction, Save_K )
		String S_Hole, S_Core, Correction, Save_K
		SetDataFolder root:
			String/G G_Hole, G_YesNo, G_Save_K
			Variable/G G_Core_Num, G_SectionNum, G_Section
			String K_List, S_Core_Name, Section, S1, S2
			G_Hole = S_Hole; G_YesNo = Correction; G_Save_K = Save_K; G_Core_Num = Str2Num( S_Core )  // Resets some globals to local values
			PauseUpdate;
		
			If( G_Core_Num < 10 )		// Makes sure that core image numbers <10 have a zero in front of the number in the wave name
				S_Core = "0" + S_Core
			EndIf
			S_Core_Name = S_Hole + "_" + S_Core		// Creates the core name from the hole and core number
			Print S_Core_Name		
			String Folder = "root:K_" + S_Core_Name
	
			If( DataFolderExists( Folder ) )
				SetDataFolder $Folder
			Else
				ABORT "Can't find the \"K_\" DataFolder with the section images in root: \rYou may need to remove the core Type from the folder name for older K folders."
			EndIf
			If( !StrLen( WaveList( "*", ";", "" ) ) )
				ABORT "The \"K_\" DataFolder in root: appears to be empty. "
			EndIf
	
			String ImageFldr = GetDataFolder( 1 )
	
			If( StringMatch( Correction, "Y" ) || StringMatch( Correction, "y" ) )  // Checks to see whether lighting correction is applied
				Lighting_Correction_by_Core_DF(  )
				RGB_Lighting_Correction_DF()
				K_List = WaveList( "C_*", ";", "" )  // List of Section Images (Note that this change from the line below is to accomodate non-ocean drilling names)
			Else
				K_List = WaveList( "K_*", ";", "" )  // List of Section Images (Note that this change from the line below is to accomodate non-ocean drilling names)
			EndIf
		
			Variable i = 0, Top_Depth, Bottom_Depth, Y_Resolution, Y_Points, Section_Bottom, Section_Top, Length
		
			Top_Depth = LeftX( $StringFromList( 0, K_List ) )		// Copies top depth of core image from top of first section image
			S1 = StringFromList( ItemsInList( K_List ) - 1, K_List )			// Next 3 steps set length (in m) of new core image using bottom depth of last section image
			Bottom_Depth = RightX( $S1 )
			Length = Bottom_Depth - Top_Depth
		
			Do										// This loop copies the section images into a blank core image
				Section = StringFromList( i, K_List )			// Pulls section name from list of section images							
				If( StrLen( Section ) < 2 )						// Checks for end of list
					Break;
				EndIf
				WAVE Sect = $Section
				If( i == 0 )										// First time through, a blank core image is formed
					Y_Resolution = DimDelta( Sect, 1 )		// These 2 lines copy the Y resolution from the section images
					Y_Points = DimSize( Sect, 1 )
					Make/B/O/N=( ( Length / .0005 ), Y_Points, 3 ) $S_Core_Name // Makes the core image Length/.0005 depth points
					WAVE Core = $S_Core_Name
					SetScale/P x Top_Depth, .0005, "m", Core			// Sets depth (X) scale
					SetScale/P y DimOffset( Sect, 1 ), Y_Resolution, "", Core  // Sets Y scale
				EndIf	
		
				Section_Top = LeftX( Sect )		// gets section top depth from section image 
				Section_Bottom = RightX( Sect )	// gets section bottom depth from section image
				Variable SecPixLen = ( ( Section_Bottom - Section_Top ) / .0005 ) + 1  // Calculates number of pixels needed at core image resolution
				ImageInterpolate/RESL = { SecPixLen, 101 } /DEST = NewSection bilinear Sect;  // Interpolates section image to new image at 0.0005 resolution
				Redimension/B/U NewSection  // Sets image to 8 bit unsigned integer
		
				Core[ X2Pnt( Core, Section_Top ), X2Pnt( Core,Section_Bottom ) ][][] = NewSection[ p - X2Pnt( Core, Section_Top ) ][ q ][ r ]	// Copies section image into core image
				i += 1
			While( 1 )
		
			If( StringMatch( Correction, "Y" ) || StringMatch( Correction, "y" ) )  // Checks to see whether lighting correction is applied and adds a Wave Note
				Note $S_Core_Name "Lighting Corrected"				//
			EndIf
			Duplicate/O Core $"root:" + S_Core_Name // Copies core image into root:
			KillWaves/Z Core, NewSection  // Deletes core image and final interpolated section image in section image folder
			
			If( StringMatch( Correction, "Y" ) || StringMatch( Correction, "y" ) ) // If lighting correction was applied, gets rid of temporary corrected section waves
				S1 = WaveList( "C_*", ",", "" )
				i = 0;
				Do
					S2 = StringFromList( i, S1 )
					If( StrLen( S2 ) < 2 )
						Break;
					EndIf
					EXECUTE "KillWaves " + S2
					i += 1	
				While( 1 ) 	
			EndIf
	
			If ( !StringMatch( GetDataFolder( 0 ) , "*root*" ) )
				If( StringMatch( Save_K, "N" ) || StringMatch( Save_K, "n" ) ) 
					KillWaves/F/A/Z
				EndIf
	
				DFREF DFldr = GetDataFolderDFR( )
				SetDataFolder root:
		
				If( StringMatch( Save_K, "N" ) || StringMatch( Save_K, "n" ) ) // save raw section images into new data folder
					KillDataFolder/Z DFldr
				EndIf
			EndIf
	
			WAVE Section_End_Pixel
			If( Exists( "Section_End_Pixel" ) ) 		// Resets pixel section end wave to NaN for core box photos
				Section_End_Pixel = NaN
			EndIf
			
			G_Section = 1						// Resets Section number to 1 for Section_Cut()
			If( !mod( Str2Num( S_Core ), 5 ) )		// Saves experiment every 5 tiimes the macro is run
				SaveExperiment
			EndIf
			DoWindow Core_Image				// This line and the following If statement check to see if a core image is already open
			If( V_Flag )							// If it is, the window is closed
				KillWindow Core_Image
			EndIf
			Redimension/B/U $S_Core_Name	// The new core image is changed to an unsigned bit format if the section images were not already
			Display/W=( 620, 96,1850, 264 )		// Opens blank graph
			DoWindow/C Core_Image			// Changes name of blank graph
			AppendImage $S_Core_Name		// Appends core image to blank graph
			ModifyGraph nticks( bottom ) = 20, minor( bottom ) = 1		// Sets a few graph mods
			SetAxis/A/R left
			G_Core_Num += 1;	G_SectionNum = 1		// Reset a couple of globals for the next run
	EndMacro
		
	
	*************************************************************************************************************
