#pragma rtGlobals=1		// Use modern global access method.
	
	---------------------------------------------------------------------
	
	Function CSI_From_Depth( )
		SetDataFolder root:
			String/G G_Site, G_Hole, G_DepthScale, G_CCInclude
			String Site = G_Site, Hole = G_Hole, DepthScale = G_DepthScale, CCInclude = G_CCInclude
			Variable/G G_Depth
			Variable Depth = G_Depth
			Prompt Hole, "Hole"
			Prompt DepthScale, "Depth Scale", popup, "CCSF; CSF"
			Prompt Depth, "Depth"
			Prompt CCInclude, "Include Core Catchers?", popup, "N;Y"
			DoPrompt "CSI_From_Depth", Hole, DepthScale, Depth, CCInclude; AbortOnValue V_Flag, 0
			Site = RemoveEnding( Hole )
			G_Site = Site, G_Hole = Hole, G_DepthScale = DepthScale; G_CCInclude = CCInclude
			Variable/G G_Depth = Depth
			CSI_From_Depth_F( Hole, DepthScale, Depth, CCInclude )
			Print "\rCSI_From_Depth_F( \"" + Hole + "\", \"" + DepthScale + "\",", Depth, ", \"" + CCInclude + "\" )"
	End

	---------------------------------------------------------------------
	
	Function CSI_From_Depth_F( Hole, DepthScale, Depth, CCInclude )
			String Hole, DepthScale, CCInclude
			Variable Depth
		SetDataFolder root:
			String HoleLetter = Hole[ StrLen( Hole ) - 1 ]
			String/G G_Site, G_Hole, G_DepthScale, G_CCInclude
			Variable/G G_Depth,	 G_i, G_j, G_Interval, G_CSF, G_CCSF
			Variable i = 0, j = 1, Interval, CC
			Variable V1 = 0, MatrixLayer = 0, CSF, CCSF
			G_Hole = Hole; G_DepthScale = DepthScale; G_CCInclude = CCInclude
			Variable/G G_Depth = Depth
			If( Exists( Hole + "_Coring_Matrix" ) )
				WAVE CMatrix = $Hole + "_Coring_Matrix"
			Else
				Abort Hole + "_Coring_Matrix \ris not in the root: directory."
			EndIf
			If( Stringmatch( DepthScale, "CCSF" ) )
				MatrixLayer = 2				// MatrixLayer defines whether CSF or CCSF was selected as the depth scale 0 = CSF, 2 = CCSF per layers in the coring matrix
			EndIf
			If( StringMatch( CCInclude, "Y" ) ) // This determines whether CC depths are included as the function works through the coring matrix
				CC = 10  // searches through column 9
			Else
				CC = 9 //  searches only columns 1 - 8
			EndIf
			For( i = 1; i < DimSize( CMatrix, 0 ); i += 1 )  // Variable i steps through the coring matrix row by row
				For( j = 1; j < CC; j += 1 )										// Variable j steps through each section in the row defined by i
					If( CMatrix[ i ][ j ][ MatrixLayer ] + CMatrix[ i ][ j ][ 1 ] > Depth ) // This line adds section length to each section depth and then checks to see if it exceeds the input depth.
						Interval = Round( ( Depth - CMatrix[ i ][ ( j ) ][ MatrixLayer ] ) * 100 )  // Interval is calculated by section depth from input depth	
						If( Interval < 0 ) // Once the section depth + section length is > input depth the loop breaks
							Break;
						EndIf
						// Results are printed to History.
						CSF = CMatrix[ i ][ j ][ 0 ] + Interval / 100; CCSF = CMatrix[ i ][ j ][ 2 ] + Interval / 100
						Printf "\r%s\t%s\t%d\tH", RemoveEnding( Hole ), HoleLetter, i
						Printf "\t %d \t  %.0f\t %.2f\t %.2f\r", j, Interval, CSF, CCSF
						V1 += 1; // Increments each time the results for an input depth are printed. See below
						Break;
					EndIf
				EndFor
			EndFor
			If( V1 > 1 ) // If there was more than 1 result, a message is printed.
				DoAlert 0, "There is more than 1 solution for depth " + Num2Str( Depth ) +". \rThis is probably the result of overlap in core depth ranges.";
			EndIf
	EndMacro

	---------------------------------------------------------------------
	
	Function CSI_From_List( )
		SetDataFolder root:
			String/G G_Site, G_Folder, G_HoleWv, G_DepthWv, G_CCInclude, G_DepthScale
			String Site = G_Site, DepthScale = G_DepthScale, Folder = G_Folder, CCInclude = G_CCInclude
			String S_Hole, Hole_List = G_HoleWv, Depth_List = G_DepthWv
			Variable i = 0, j, k, V1, V2, Depth, MatrixLayer, Interval, CC
			Prompt Folder, "Data Folder", popup, "root:;" + FolderList( "*" )
			DoPrompt "CSI_from_List", Folder; AbortonValue V_Flag, 0
			If( !StringMatch( Folder, "root:" ) )
		SetDataFolder $"root:" + Folder
			EndIf
			Prompt DepthScale, "Depth Scale", popup, ( "CCSF;CSF" )
			Prompt Site, "Site"
			Prompt Hole_List, "Hole List", popup, SortList( WaveList( "*", ";", "TEXT:1" ) )
			Prompt Depth_List, "Depth List", popup, SortList( WaveList( "*", ";", "TEXT:0" ) )
			Prompt CCInclude, "Include Core Catchers?", popup, "N;Y"
			DoPrompt "CSI_From_List", DepthScale, Site, Hole_List, Depth_List, CCInclude;
			If( V_Flag )
				SetDataFolder root:; Abort
			EndIf
			WAVE/T HoleW = $Hole_List
			WAVE DepthW = $Depth_List
		SetDataFolder root:
			G_Site = Site; G_Folder = Folder; G_HoleWv = Hole_List; G_DepthWv = Depth_List;
			G_CCInclude = CCInclude; G_DepthScale = DepthScale
			If( Stringmatch( DepthScale, "CCSF" ) )
				MatrixLayer = 2
			EndIf
			If( StringMatch( CCInclude, "Y" ) )
				CC = 10
			Else
				CC = 9
			EndIf	
			CSI_from_List_F( Folder, DepthScale, Site, Hole_List, Depth_List, CCInclude )
			Print "\rCSI_from_List_F( \"" + Folder + "\", \"" + DepthScale + "\", \"" + Site + "\", \"" + Hole_List + "\", \"" + Depth_List + "\", \"" + CCInclude + "\" )"
	End
	
	---------------------------------------------------------------------
	
	Function CSI_from_List_F( Folder, DepthScale, Site, Hole_List, Depth_List, CCInclude )
		String Folder, DepthScale, Site, Hole_List, Depth_List, CCInclude
		SetDataFolder root:
			String/G G_Site, G_Folder, G_HoleWv, G_DepthWv, G_CCInclude, G_DepthScale
			String S_Hole
			Variable i = 0, j, k, V1, V2, Depth, MatrixLayer, Interval, CC
			If( !StringMatch( Folder, "root:" ) )
		SetDataFolder $"root:" + Folder
			EndIf
			WAVE/T HoleW = $Hole_List
			WAVE DepthW = $Depth_List
			WaveStats/Q DepthW
		NewDataFolder/O/S $"root:CSI_OutPut"
			Duplicate/O/T HoleW SiteOut, HoleOut, TypeOut
			SiteOut = Site; HoleOut = ""; TypeOut = "H"
			Duplicate/O DepthW CoreOut, SectionOut, IntervalOut, CSFOut, CCSFOut
			CoreOut = NaN; SectionOut = NaN; IntervalOut = NaN; CSFOut = NaN; CCSFOut = NaN
		SetDataFolder root:
			G_Site = Site; G_Folder = Folder; G_HoleWv = Hole_List; G_DepthWv = Depth_List; G_CCInclude = CCInclude
			If( Stringmatch( DepthScale, "CCSF" ) )
				MatrixLayer = 2
			EndIf
			If( StringMatch( CCInclude, "Y" ) )
				CC = 10
			Else
				CC = 9
			EndIf
			For( k = 0; k < V_Npnts; k += 1 )	// K steps through the depths in the depth list
				If( Exists( Site + HoleW[ k ] + "_Coring_Matrix" ) ) // Checks to se if the coring matrix is in root: and then sets a wave reference for the right hole
					WAVE CMatrix = $Site + HoleW[ k ] + "_Coring_Matrix" 
				Else
					Abort Site + HoleW[ k ] + "_Coring_Matrix \ris not in the root: directory."
				EndIf
				For( i = 0; i < DimSize( CMatrix, 0 ); i += 1 )  //  i steps through the coring matrix row by row. i represents the ore number
					For( j = 1; j < CC; j += 1 )										//  j steps through each section in the row defined by i. j represents the section number.
						If( CMatrix[ i ][ j ][ MatrixLayer ] + CMatrix[ i ][ j ][ 1 ] > DepthW[ k ] ) // This line adds section length to each section depth and then checks to see if it exceeds the input depth.
							Interval = Round( ( DepthW[ k ] - CMatrix[ i ][ ( j ) ][ MatrixLayer ] ) * 100 )  // Interval is calculated by section depth from input depth	
							If( Interval < 0 ) // Once the section depth + section length is > input depth the section loop breaks
								Break;
							EndIf
							V1 += 1;   // Increments each time the results for an input depth are printed. 
							If( V1 > 1 ) // If there was more than 1 result, a message is printed.
								If( !V2 )
									V2 = 1
									DoAlert 0, "There are 2 solutions for one or more depths.\rThe second solutions are printed in History and are not in the output waves.";
								EndIf
								Printf "%s\t%s\t %d \tH\t %d\t %d\t %0.2f\t %0.2f\r", Site, HoleW[ k ], i, j, Interval, CMatrix[ i ][ j ][ 0 ] + Interval / 100, CMatrix[ i ][ j ][ 2 ] + Interval / 100									
							Else
								HoleOut[ k ] = HoleW[ k ]; CoreOut[ k ] = i; SectionOut[ k ] = j; IntervalOut[ k ] = Interval
								CSFOut[ k ] = CMatrix[ i ][ j ][ 0 ] + Interval / 100; CCSFOut[ k ] = CMatrix[ i ][ j ][ 2 ] + Interval / 100
								Break;
							EndIf
						EndIf
					EndFor  	// the j loop	( sections )
				EndFor 		// the i loop   ( cores )
				V1 = 0 			// Reset the check for multiple solutions before the next depth is processed
			EndFor 			// the k loop   ( input depths )
			If( StrSearch( WinList("*",";","WIN:2"), "CSICalculations", 0, 2 ) == -1 )
				Preferences 1
				Edit/N = CSICalculations SiteOut, HoleOut, CoreOut, TypeOut, SectionOut, IntervalOut, CSFOut, CCSFOut as "CSI Calculations"
				ModifyTable format( CSFOut ) = 3, digits( CSFOut ) = 2,  format( CCSFOut ) = 3, digits( CCSFOut ) = 2
				ModifyTable alignment = 1
			EndIf
			Print "\r"
		SetDataFolder root:
	End	
	
	---------------------------------------------------------------------

	Function CSI_from_SpliceDepth()
		SetDataFolder root:
			String/G G_Site, G_CCInclude
			String Site = G_Site, Hole, CMatrix, Folder, CCInclude
			Variable/G G_Depth
			Variable Depth = G_Depth, i
			Prompt Site, "Site"	
			Prompt Depth, "Depth ( CCSF )"
			DoPrompt "CSI_from_SpliceDepth", Site, Depth; AbortOnValue V_Flag, 0
			G_Depth = Depth; G_Site = Site			
			CSI_from_SpliceDepth_F( Site, Depth )
			Print "\rCSI_from_SpliceDepth_F( \"" + Site + "\",", Depth,")"
	End
	
	---------------------------------------------------------------------

	Function CSI_from_SpliceDepth_F( Site, Depth )
			String Site
			Variable Depth
		SetDataFolder root:
			String/G G_Site, G_CCInclude
			String Hole, CMatrix, Folder, CCInclude
			Variable/G G_Depth
			Variable i
			If( StrSearch( FolderList( "*" ), Site + "_Splice_Intervals", 0 ) == -1 )
				Abort "Can't find folder " + Site + "_Splice_Intervals\rYou need to run a splice format conversion function."
			EndIf
		SetDataFolder $Site + "_Splice_Intervals"
			WAVE CCSF_Top, CCSF_Bottom
			WAVE/T Hole_Top
		SetDataFolder root:
			For( i = 0; i < NumPnts( CCSF_Bottom ); i += 1 )  // This loop cycles through the Splice_Intervals to identify the Hole
				If( Depth >= CCSF_Top[ i ] && Depth <= CCSF_Bottom[ i ] )
				 Hole = Hole_Top[ i ]
				EndIf
			EndFor
			Hole = Site + Hole
			CSI_From_Depth_F( Hole, "CCSF", Depth, "N" )		
		End
	
	---------------------------------------------------------------------
	
	Function CSI_from_SpliceList( )
		SetDataFolder root:
			String/G G_Site, G_Folder, G_DepthWv
			String Site = G_Site, Folder = G_Folder
			String Depth_List = G_DepthWv
			Variable i, j, Depth
			Prompt Site, "Site"
			Prompt Folder, "Data Folder", popup, "root:;" + FolderList( "*" )
			DoPrompt "CSI_from_SpliceList", Site, Folder; AbortOnValue V_Flag, 0
			G_Site = Site; G_Folder = Folder
			If( !Stringmatch( "root:", Folder ) )
		SetDataFolder $"root:" + Folder	
			EndIf
			Prompt Depth_List, "Depth Wave", popup, SortList( WaveList( "*", ";", "" ) )
			DoPrompt "CSI_from_SpliceList", Depth_List
			G_DepthWv = Depth_List
			If( V_Flag )
				SetDataFolder root:; Abort// If the user cancels while the pointer is in the data subfolder, pointer returns to root:
			EndIf
			WAVE DepthW = $Depth_List
		SetDataFolder root:
			CSI_from_SpliceList_F( Site, Folder, Depth_List )
			Print "\rCSI_from_SpliceList_F( \"" + Site + "\", \"" + Folder + "\", \"" + Depth_List + "\" )"
	End

	---------------------------------------------------------------------

	Function CSI_from_SpliceList_F( Site, Folder, Depth_List )
		String Site, Folder, Depth_List
		SetDataFolder root:
			String/G G_Site, G_Folder, G_DepthWv
			Variable i, j, Depth
			G_Site = Site; G_Folder = Folder; G_DepthWv = Depth_List
			If( !Stringmatch( "root:", Folder ) )
		SetDataFolder $"root:" + Folder	
			EndIf
			WAVE DepthW = $Depth_List
		SetDataFolder root:
			If( StrSearch( FolderList( "*" ), Site + "_Splice_Intervals", 0 ) == -1 )
				Abort "Can't find folder " + Site + "_Splice_Intervals\rYou need to run a splice format conversion function or load the folder."
			EndIf
		SetDataFolder $Site + "_Splice_Intervals" 
			WAVE CCSF_Top, CCSF_Bottom
			WAVE/T Hole_Top
		SetDataFolder root:
			Make/O/T/N = ( NumPnts( DepthW ) ) Hole_List
			For( i = 0; i < NumPnts( DepthW ); i += 1 ) // Cycles through list of depths
				For( j = 0; j < NumPnts( CCSF_Top ); j += 1 ) // Cycles through the splice interval depths
					If( DepthW[ i ] >= CCSF_Top[ j ] && DepthW[ i ] <= CCSF_Bottom[ j ] )
					 Hole_List[ i ] = Hole_Top[ j ]
					EndIf
				EndFor
			EndFor		
			CSI_from_List_F( Folder, "CCSF", Site, "root:Hole_List", Depth_List, "N" )
			KillWaves/Z Hole_List
	End

	---------------------------------------------------------------------
	
	Function CSI_From_CsrA_CCSF( )
		If( !StrLen( CsrWave( A ) ) )
			ABORT "Cursor A Not On Graph"
		EndIf
		String WName = CsrWave( A ), Hole, Site
		Variable Depth = HCsr( A )
		If( StrSearch( WName, "Splice", 0, 2 ) + 1 )			
			Site = DataWaveSite( WName )
			CSI_from_SpliceDepth_F( Site, Depth )
		Else
			Hole = DataWaveHole( WName )
			CSI_From_Depth_F( Hole, "CCSF", Depth, "Y" )
		EndIf
	End
	
	---------------------------------------------------------------------
			
	Function CSI_From_CsrB_CCSF( )
		If( !StrLen( CsrWave( B ) ) )
			ABORT "Cursor B Not On Graph"
		EndIf
		String WName = CsrWave( B ), Hole, Site
		Variable Depth = HCsr( B )
		If( StrSearch( WName, "Splice", 0, 2 ) + 1 )			
			Site = DataWaveSite( WName )
			CSI_from_SpliceDepth_F( Site, Depth )
		Else
			Hole = DataWaveHole( WName )
			CSI_From_Depth_F( Hole, "CCSF", Depth, "Y" )
		EndIf
	End
	
	---------------------------------------------------------------------
			
	// This macro is used as a subroutine when printing ties so that the ties can be printed on the same line.
	
	Function CSI_From_CCSF_NoReturn( S_Hole, MCD )
		Variable MCD
		String S_Hole
		Variable i = 0, j =1, k = 0, Int
		NVAR V1 = root:G_V1; V1 = 0
		WAVE CMatrix = $S_Hole+"_Coring_Matrix"
		k = DimSize( $S_Hole + "_Coring_Matrix", 0 ) - 1
		Do
			j = 1
			Do
				If( CMatrix[ i ][ j ][ 2 ] + CMatrix[ i ][ j ][ 1 ] > MCD )
					Int = Round( ( MCD - CMatrix[ i ][ ( j ) ][ 2 ] ) * 100 )	
					Printf "\t%s\t%s\t%d\tH", S_Hole[ 0, StrLen( S_Hole ) - 2 ], S_Hole[ StrLen( S_Hole ) - 1 ], i
					Printf "\t%d\t  %.0f\t%.2f\t%.2f", j, Int, CMatrix[ i ][ j ][ 0 ] + Int / 100, MCD
					V1 = 1;
					Break;
				EndIf
				j += 1;
			While( j < 10 )
			If( V1 )
				Break;
				EndIf
			i += 1
		While( i < k )
	EndMacro
	
	---------------------------------------------------------------------
	
	Function CSI_From_Depth_NoReturn( Site, Hole, DepthScale, Depth, CCInclude )
		String Site, Hole, DepthScale, CCInclude
		Variable Depth
		DFREF DFldr = GetDataFolderDFR()
		SetDataFolder root:
			String/G G_Site, G_Hole, G_DepthScale, G_CCInclude
			Variable/G G_Depth,	 G_i, G_j, G_Interval, G_CSF, G_CCSF
			Variable i = 0, j = 1, Interval, CC
			Variable V1 = 0, MatrixLayer = 0, CSF, CCSF
			G_Site = Site; G_Hole = Hole; G_DepthScale = DepthScale; G_CCInclude = CCInclude
			Variable/G G_Depth = Depth
			If( Exists( Site + Hole + "_Coring_Matrix" ) )
				WAVE CMatrix = $Site + Hole + "_Coring_Matrix"
			Else
				Abort Site + Hole + "_Coring_Matrix \ris not in the root: directory."
			EndIf
			If( Stringmatch( DepthScale, "CCSF" ) )
				MatrixLayer = 2				// MatrixLayer defines whether CSF or CCSF was selected as the depth scale 0 = CSF, 2 = CCSF per layers in the coring matrix
			EndIf
			If( StringMatch( CCInclude, "Y" ) ) // This determines whether CC depths are included as the function works through the coring matrix
				CC = 10  // searches through column 9
			Else
				CC = 9 //  searches only columns 1 - 8
			EndIf
			For( i = 1; i < DimSize( CMatrix, 0 ); i += 1 )  // Variable i steps through the coring matrix row by row
				For( j = 1; j < CC; j += 1 )										// Variable j steps through each section in the row defined by i
					If( CMatrix[ i ][ j ][ MatrixLayer ] + CMatrix[ i ][ j ][ 1 ] > Depth ) // This line adds section length to each section depth and then checks to see if it exceeds the input depth.
						Interval = Round( ( Depth - CMatrix[ i ][ ( j ) ][ MatrixLayer ] ) * 100 )  // Interval is calculated by section depth from input depth	
						If( Interval < 0 ) // Once the section depth + section length is > input depth the loop breaks
							Break;
						EndIf
						// Results are printed to History.
						CSF = CMatrix[ i ][ j ][ 0 ] + Interval / 100; CCSF = CMatrix[ i ][ j ][ 2 ] + Interval / 100
						Printf "%s\t%s\t%d\tH", Site, Hole, i
						Printf "\t %d \t  %.0f\t %.2f\t %.2f", j, Interval, CSF, CCSF
						V1 += 1; // Increments each time the results for an input depth are printed. See below
						Break;
					EndIf
				EndFor
			EndFor
			If( V1 > 1 ) // If there was more than 1 result, a message is printed.
				DoAlert 0, "There is more than 1 solution for depth " + Num2Str( Depth ) +". \rThis is probably the result of overlap in core depth ranges.";
			EndIf
		SetDataFolder DFldr
	EndMacro


