#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// Auto_Edit_Curves fits a 3d order polynomial curve to the intensity data for one of the colors.
//		It then deletes points outside of 95% confidence level to eliminate spikes.
	
	Function Auto_Edit_Curves()
		WAVE Lightness, Interval
		DelayUpdate;
		CurveFit/Q/NTHR=0 poly 3,  Lightness /X = Interval /D /F = { 0.95000, 3 } // The curve fitting routine
		WAVE UP_Lightness, LP_Lightness  // UP and LP are the upper and lower 95% confidence level curves
		Duplicate/O Lightness  Mask
		Duplicate/O UP_Lightness UP_Lightness_x
		UP_Lightness_x = x
		
		Mask = interp( Interval, UP_Lightness_x, LP_Lightness ) - Lightness > 0  // Identifies where lightness values are > 95%
																											  // by making Mask zeroes and ones
		Sort Mask  Interval, Lightness, Mask  //  Sorts lightness and interval by Mask, e.g. ones and zeroes
		FindLevel/Q Mask, 1  // Finds out where the 1/0 divide is in the sorted data
		If( V_LevelX > 0 )
			DeletePoints V_LevelX, ( NumPnts( Mask ) - V_LevelX ), Interval, Lightness, Mask // Deletes points greater than 95%
		EndIf
			
		Mask = interp( Interval, UP_Lightness_x, UP_Lightness ) - Lightness < 0  // Identifies points less than 95% level
		Sort Mask  Interval, Lightness, Mask
		FindLevel/Q Mask, 1
		If( V_LevelX > 0 )
			DeletePoints V_LevelX, ( NumPnts( Mask ) - V_LevelX ), Interval, Lightness, Mask  // Deletes lower points
		EndIf	

		Sort Interval Lightness, Interval  // Sorts lightness and interval curves back to depth order
		KillWaves/Z UC_Lightness, LC_Lightness, UP_Lightness, LP_Lightness, UP_Lightness_x
		KillWaves/Z W_coef, W_Sigma, W_ParamConfidenceInterval
		KillWaves/Z Mask
	EndMacro
	
	**********************************************************
	
//	Function Edit_Lightness_Box()
		Variable XMax,XMin,YMax,Ymin
		WAVE Lightness, Interval, Index, Mask
		Silent 1;
		PauseUpdate;
		SetDataFolder root:
		GetAxis/Q Left
		YMax=V_Max;YMin=V_Min
		GetAxis/Q Bottom
		XMax=V_Max;XMin=V_Min
		Duplicate/O Lightness  Mask
		Mask=(Interval<XMax&&Interval>XMin)&&(Lightness<YMax&&Lightness>YMin)
		If(Sum(Mask)>3000)
			Abort "More Than 3000 Points!"
		EndIf
		Sort Mask  Index,Interval,Lightness,Mask
		FindLevel/Q Mask, 1
		DeletePoints V_LevelX, (NumPnts(Mask)-V_LevelX) ,Index,Interval,Lightness,Mask
		KillWaves/Z Mask
		Sort Interval Lightness,Index,Interval
		SetAxis/A
	End Macro
	
	****************************************************************
	
//	Function Edit_Lightness_Curve()
		Variable XMax,XMin,YMax,Ymin
		String Above_Below
		Prompt Above_Below, "Above or Below?",popup, "Delete All Above Curve;Delete All Below Curve"
		DoPrompt "",  Above_Below
		If(V_Flag)
			Abort;
		EndIf
		WAVE Lightness, Interval, Index, Mask,Corr_Curve,Corr_Curve_x
		Silent 1;
		PauseUpdate;
		GetAxis/Q Left
		YMax=V_Max;YMin=V_Min
		GetAxis/Q Bottom
		XMax=V_Max;XMin=V_Min
		Duplicate/O Lightness  Mask
		If(StringMatch(Above_Below,"Delete All Below Curve"))
			Mask=interp(Interval,Corr_Curve_x,Corr_Curve)-Lightness>0
		Else
			Mask=interp(Interval,Corr_Curve_x,Corr_Curve)-Lightness<0
		EndIf
		//ModifyGraph zColor(Lightness)={Mask,*,*,Rainbow,0}
		Sort Mask  Index,Interval,Lightness,Mask
		FindLevel/Q Mask, 1
		DeletePoints V_LevelX, (NumPnts(Mask)-V_LevelX) ,Index,Interval,Lightness,Mask
		KillWaves/Z Mask
		Sort Interval Lightness,Index,Interval
		SetAxis/A
	End Macro
	
//	Macro Auto_Edit_Curves()
		Silent 1
		DelayUpdate;
		CurveFit/Q/NTHR=0 poly 3,  Lightness /X=Interval /D /F={0.95000, 7}
		Duplicate/O Lightness  Mask
		Duplicate/O UP_Lightness UP_Lightness_x
		UP_Lightness_x=x
		
		Mask=interp(Interval,UP_Lightness_x,LP_Lightness)-Lightness>0
		Sort Mask  Interval,Lightness,Mask
		FindLevel/Q Mask, 1
		If(V_LevelX>0)
		DeletePoints V_LevelX, (NumPnts(Mask)-V_LevelX) ,Interval,Lightness,Mask
		EndIf
			
		Mask=interp(Interval,UP_Lightness_x,UP_Lightness)-Lightness<0
		Sort Mask  Interval,Lightness,Mask
		FindLevel/Q Mask, 1
		If(V_LevelX>0)
			DeletePoints V_LevelX, (NumPnts(Mask)-V_LevelX) ,Interval,Lightness,Mask
		EndIf
		KillWaves/Z Mask
		Sort Interval Lightness, Interval
	
	EndMacro
	
