#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// This function stacks the R, G, and B profiles from all of the sections in a core and creates waves
//  that are used in Lighting_Correction_by_Core(). The pointer is already on the "K_" folder.
	
	------------------------------
	
	Function Lighting_Curves_Core_DF( )
		String KWaveList, KWave
		Variable i = 0, j = 0, V1
		PauseUpdate;
		KWaveList = WaveList( "K_*", ";", "" )  // Makes list of section images
		Do // This is the J loop. It tells the profile function which layer to profile - R ( j = 0 ), G ( j = 1 ), or B ( j = 2 )
			Make/O/N=0 Lightness, Interval  // Lightness is a temporary intensity curve, interval is the X axis points
			i = 0;									  //      which need to be reduced from depth scaled to cm from top. This line sets them to zero length.
			Do  // This is the i loop. It goes through the image list.
				KWave = StringFromList( i, KWaveList )  // Sequentially processes section images.
				If( StrLen( KWave ) < 2 )  // Breaks loop when there are no more images to process
					Break
				EndIf
				WAVE KWv = $KWave  // WAVE assignment from string name

				Make/O /N = 2 xw, yw
				xw[ 0 ] = LeftX( KWv ); xw[ 1 ] = RightX( KWv ) //  Top and bottom depths of line profile
				yw = .5															//  Track down the middle of image with default scaling of 0 to 1
							//  ImageLineProfile makes R, G, and B profiles through a section image
				ImageLineProfile/SC/P=( j ) xWave = xw, yWave = yw, srcwave = KWv, width = ( dimsize( KWv, 1 ) / 2 )
				WAVE W_LineProfileX, W_ImageLineProfile
				V1 = W_LineProfileX[ 0 ]  // V1 is usd in a couple of ways here to "normalize" profiles and start depths at 0
				W_LineProfileX -= V1  // Starts X axis at 0
				V1 = StatsMedian( W_ImageLineProfile )  // Sets V1 to median of intensity profile values
				W_ImageLineProfile -= V1  // Subtracts median from profile to account for shifts in overall lightness, such as color change in core
				Concatenate/NP "W_LineProfileX;", Interval // Intervals and intensities from each section are concatenated into a single wave.
				Concatenate/NP "W_ImageLineProfile;", Lightness
				i += 1
			While( 1 )
			If( j == 0 )
				Duplicate/O Lightness Lightness_R  // Saves the Red profiles of all of the sections with a unique name
				Duplicate/O Interval Interval_R
			EndIf
			If( j == 1 )
				Duplicate/O Lightness Lightness_G  // Saves the Green profiles of all of the sections with a unique name
				Duplicate/O Interval Interval_G
			EndIf
			If( j == 2 )
				Duplicate/O Lightness Lightness_B  // Saves the Blue profiles of all of the sections with a unique name
				Duplicate/O Interval Interval_B
			EndIf
			KillWaves/Z Lightness, Interval
			j += 1
		While( J < 3 )
		KillWaves/Z W_ImageLineProfile, W_LineProfileX, xw, yw
		KillWaves/Z W_LineProfileY, W_coef, W_sigma, W_ParamConfidenceInterval
	EndMacro
	
	------------------------------
	
	Function Lighting_Curves_Core(Folder)
		String Folder
		String KWaveList, KWave
		Variable i = 0, j = 0, V1
		SetDataFolder root:
		PauseUpdate;
		SetDataFolder $"root:" + Folder
		KWaveList = WaveList( "K_*", ";", "" )
		SetDataFolder root:
		Do
		Make/O/N=0 Lightness, Interval
			i = 0;
			Do
				KWave = StringFromList( i, KWaveList )
				If( StrLen( KWave ) < 2 )
					Break
				EndIf
				KWave = "root:" + Folder + ":" + KWave
				WAVE KWv = $KWave
				Duplicate/O KWv Temp_Section
				Make/O/N=( dimsize( $KWave, 0 ) ) xw, yw
				xw = dimoffset( KWv, 0 ) + dimdelta( KWv, 0 ) * x
				yw = dimoffset( KWv,1 ) + dimdelta( KWv, 1 ) * ( dimsize( KWv, 1 ) / 2 )
				ImageLineProfile/SC/P=( j ) xWave = xw, yWave = yw, srcwave = Temp_Section, width = ( dimsize( KWv, 1 ) / 4 )
				WAVE W_LineProfileX, W_ImageLineProfile
				V1 = W_LineProfileX[ 0 ]  // V1 is usd in a couple of ways here to "normalize" profiles and start depths at 0
				W_LineProfileX -= V1
				V1 = StatsMedian( W_ImageLineProfile )
				W_ImageLineProfile -= V1
				Concatenate/NP "W_LineProfileX;", Interval
				Concatenate/NP "W_ImageLineProfile;", Lightness
				i += 1
			While( 1 )
			If( j == 0 )
				Duplicate/O Lightness Lightness_R
				Duplicate/O Interval Interval_R
			EndIf
			If( j == 1 )
				Duplicate/O Lightness Lightness_G
				Duplicate/O Interval Interval_G
			EndIf
			If( j == 2 )
				Duplicate/O Lightness Lightness_B
				Duplicate/O Interval Interval_B
			EndIf
			KillWaves/Z Lightness, Interval
			j += 1
		While( J < 3 )
		KillWaves/Z W_ImageLineProfile, W_LineProfileX, xw, yw
		KillWaves/Z W_LineProfileY, Temp_Section, W_coef, W_sigma, W_ParamConfidenceInterval
	EndMacro
	
	------------------------------
