#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// This function checks to see that all of the splice data waves are of the same length. 
// For splice ties, the "Bottom" waves are 1 point longer than the "Top" waves. The are equal for splice intervals.

// Last chenged 17/6/2017 to add the splice format to the arguments so that only the splice data folder selected is checked.

	Function SpliceDataCheck( Site, Splice_Format )
		String Site, Splice_Format
		DFREF DFR = GetDataFolderDFR(); SetDataFolder root:	 // The first part of this line records the active datafolder when the function is called.
		DFREF IntervalFldr = $Site + "_Splice_Intervals", TieFldr = $Site + "_Splice_Ties"
		String WList
		Variable i = 0, TPoints, BPoints

// The first set checks the splice intervals. They should all be the same length.

		If( DataFolderExists( Site + "_Splice_Intervals" )  && StringMatch( Splice_Format, "Splice_Intervals" ) )
			SetDataFolder IntervalFldr
			WList = WaveList( "*", ";", "" )
			TPoints = NumPnts( $StringFromList( 0, WList ) );
			i = 0 
			Do
				If( NumPnts( $StringFromList( i, WList ) ) != TPoints )
					DoAlert/T = "Splice Data Problem" 1, "The Data Waves in the Splice_Interval Folder are of unequal length.\r\rYou should fix this before proceeding. The problem is often the Comment or Tie wave.\r\rDo you want to continue?"
					If( V_Flag == 2 )
						SetDataFolder DFR
						Return 1
						Abort
					Else
						Break
					EndIf
				Endif		
				i+= 1
			While( i < ItemsInList( WList ) )	
		EndIf
		SetDataFolder DFR  // Returns active folder to the same as when the function was called.		

//  Here we check the lengths of Top and Bottom waves and then make sure Bottoms are 1 point longer than Tops

		If( DataFolderExists( Site + "_Splice_Ties" )  && StringMatch( Splice_Format, "Splice_Ties" ) )
			SetDataFolder TieFldr
			WList = WaveList( "*Top", ";", "" )
			TPoints = NumPnts( $StringFromList( 0, WList ) );
			i = 0 
			Do
				If( NumPnts( $StringFromList( i, WList ) ) != TPoints )
					DoAlert/T = "Splice Data Problem" 1, "The Top & Bottom Waves in the Splice_Tie Folder are of equal length.\rThe bottom of the last interval may be missing\rYou should fix this before proceeding.\r\rDo you want to continue?"
					If( V_Flag == 2 )
						SetDataFolder DFR
						Return 1
						Abort
					Else
						Break
					EndIf
				Endif		
				i+= 1
			While( i < ItemsInList( WList ) )	

			i = 0 
			WList = WaveList( "*Bottom", ";", "" )
			BPoints = NumPnts( $StringFromList( 0, WList ) );
			Do
				If( NumPnts( $StringFromList( i, WList ) ) != BPoints )
					DoAlert/T = "Splice Data Problem" 1, "The \"Bottom\" Data Waves in the Splice_Tie Folder are of unequal length.\r\rYou should fix this before proceeding.\r\rDo you want to continue?"
					If( V_Flag == 2 )
						SetDataFolder DFR
						Return 1
						Abort
					Else
						Break
				EndIf
			Endif		
				i+= 1
			While( i < ItemsInList( WList ) )	
		EndIf
	
		If( BPoints == TPoints )
			DoAlert/T = "Splice Data Problem" 1, "The \"Bottom\" Data Waves are the same length as the \"Tops\".\rThe Bottoms should be 1 point longer to accomodate the bottom of the final interval.\rYou should fix this before proceeding.\r\rDo you want to continue?"
			If( V_Flag == 2 )
				SetDataFolder DFR
				Return 1
				Abort
			EndIf
		Endif		
			
		SetDataFolder DFR  // Returns active folder to the same as when the function was called.	
	End
	
